pub enum LineSide {
Left,
On,
Right,
}Expand description
The algebraic side of a point relative to a directed line.
Variants
Left
The point has positive orientation relative to the line.
On
The point is exactly collinear with the line.
Right
The point has negative orientation relative to the line.