VisionEvent

Enum VisionEvent 

pub enum VisionEvent {
    Entered {
        track_id: TrackId,
        zone_id: ZoneId,
    },
    Exited {
        track_id: TrackId,
        zone_id: ZoneId,
    },
    Crossed {
        track_id: TrackId,
        zone_id: ZoneId,
        direction: Direction,
    },
}
A membership or crossing transition observed for a track and zone.

Variants



Entered

A track entered a polygon zone.

Fields

track_id: TrackId

The track that entered.

zone_id: ZoneId

The polygon zone that was entered.



Exited

A track exited a polygon zone.

Fields

track_id: TrackId

The track that exited.

zone_id: ZoneId

The polygon zone that was exited.



Crossed

A track crossed a finite line zone.

Fields

track_id: TrackId

The track that crossed.

zone_id: ZoneId

The line zone that was crossed.

direction: Direction

The crossing direction relative to the directed line segment.