pub fn line_side(segment: LineSegment, point: Point) -> LineSideExpand description
Returns the algebraic side of a point relative to a directed segment.
pub fn line_side(segment: LineSegment, point: Point) -> LineSideReturns the algebraic side of a point relative to a directed segment.